#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const service_common_1 = require("@crosslab/service-common");
const express_1 = __importDefault(require("express"));
const express_async_handler_1 = __importDefault(require("express-async-handler"));
const config_1 = require("./config");
const opa_1 = require("./opa");
const openfga_1 = require("./openfga");
const app = (0, express_1.default)();
(0, service_common_1.logHandling)(app);
app.get('/authorization/status', (_req, res) => {
    res.send({ status: 'ok' });
});
app.use((req, res, next) => {
    if (req.headers['x-authorization-psk'] !== config_1.config.PSK) {
        res.status(401).send('Unauthorized');
        return;
    }
    next();
});
app.use(express_1.default.json());
app.get('/authorize', (0, express_async_handler_1.default)(async (req, res) => {
    if (typeof req.query.subject !== 'string') {
        res.send({ result: false, reason: 'subject is not a string' });
        return;
    }
    if (typeof req.query.action !== 'string') {
        res.send({ result: false, reason: 'action is not a string' });
        return;
    }
    if (typeof req.query.object !== 'string') {
        res.send({ result: false, reason: 'object is not a string' });
        return;
    }
    const check = {
        subject: req.query.subject,
        action: req.query.action,
        object: req.query.object,
    };
    res.send((await (0, opa_1.opa_check)([check]))[0]);
}));
app.post('/authorize', (0, express_async_handler_1.default)(async (req, res) => {
    const checks = req.body;
    if (!Array.isArray(checks)) {
        res.send({ result: false, reason: 'checks is not an array' });
        return;
    }
    if (checks.length === 0) {
        res.send({ result: false, reason: 'checks is empty' });
        return;
    }
    res.send(await (0, opa_1.opa_check)(checks));
}));
app.post('/relations/update', (0, express_async_handler_1.default)(async (req, res) => {
    const input = req.body;
    const add = input.add ?? [];
    const remove = input.remove ?? [];
    await (0, openfga_1.update_relations)(add, remove);
    res.send();
}));
app.post('/relations/query', (0, express_async_handler_1.default)(async (req, res) => {
    res.send(await (0, openfga_1.query_relations)(req.body.subject, req.body.relation, req.body.object));
}));
app.use(service_common_1.errorHandler);
exports.default = app;
//# sourceMappingURL=app.js.map